@@ -21,10 +21,15 @@ def render_to_pdf(report, template_src, context_dict, pdf_encoding='UTF-8'):
     html = template.render(context)
     result = StringIO.StringIO()
 
-    import ho.pisa as pisa
-    pdf = pisa.pisaDocument(StringIO.StringIO(html.encode(pdf_encoding)), result)
+    from xhtml2pdf import pisa
+    pdf = pisa.CreatePDF(StringIO.StringIO(html.encode(pdf_encoding)), result)
+
     if not pdf.err:
         response = HttpResponse(result.getvalue(), mimetype='application/pdf')
         response['Content-Disposition'] = 'attachment; filename=%s.pdf' % report.slug
-        return response
-    return HttpResponse('We had some errors<pre>%s</pre>' % escape(html))
+    else:
+        response = HttpResponse('We had some errors<pre>%s</pre>' % escape(html))
+
+    result.close()
+    return response
+
